"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.insertTest = void 0;
const gql_1 = require("@deep-foundation/deeplinks/imports/gql");
const package_name_1 = require("./package-name");
/**
 * Inserts a test link that is handled by the handler of this package to run tests for [logger](https://github.com/deep-foundation/logger) package
 *
 * @example
 * #### Insert a test link
```ts
await insertTest({
  deep,
  containerLinkId
})
```
 */
function insertTest(param) {
    return __awaiter(this, void 0, void 0, function* () {
        const { deep, containerLinkId } = param;
        const serialOperations = [];
        const reservedLinkIds = yield deep.reserve(1);
        const testLinkId = reservedLinkIds.pop();
        const testInsertSerialOperation = (0, gql_1.createSerialOperation)({
            type: 'insert',
            table: 'links',
            objects: {
                type_id: yield deep.id(package_name_1.LOGGER_TEST_PACKAGE_NAME, 'Test'),
            },
        });
        serialOperations.push(testInsertSerialOperation);
        if (containerLinkId !== null) {
            const containInsertSerialOperation = (0, gql_1.createSerialOperation)({
                type: 'insert',
                table: 'links',
                objects: {
                    type_id: yield deep.id('@deep-foundation/core', 'Contain'),
                    from_id: containerLinkId !== null && containerLinkId !== void 0 ? containerLinkId : deep.linkId,
                    to_id: testLinkId,
                },
            });
            serialOperations.push(containInsertSerialOperation);
        }
        yield deep.serial({
            operations: serialOperations,
        });
        return {
            testLinkId: testLinkId,
        };
    });
}
exports.insertTest = insertTest;
